@@ -1,7 +1,7 @@
 import types
 import warnings
 from collections import OrderedDict
-from typing import Dict, List, Callable, Union, Tuple, Optional, Type, Set, Iterable
+from typing import Dict, List, Callable, Union, Tuple, Optional, Type, Set, Iterable, Any
 
 from .config_function import ConfigFunction
 from .config_item import ConfigItem
@@ -32,7 +32,8 @@ def _is_class_method(func: Callable):
 
 
 RESERVED_CLASS = {'calc', 'list', 'set_hyperparams', 'set_meta', 'aggregate', 'calc_wrap'}
-RESERVED_INSTANCE = {'_to_json', '_reset_explicitly_specified', '_set_update_callback', '_set_values', '_get_type'}
+RESERVED_INSTANCE = {'set_default', '_to_json', '_reset_explicitly_specified', '_set_update_callback',
+                     '_set_values', '_get_type'}
 
 _STANDARD_TYPES = {int, str, bool, float, Dict, List}
 
@@ -100,8 +101,10 @@ class Configs:
     __aggregates_options: Dict[str, Set[str]]
     __secondary_values: Dict[str, Dict[str, any]]
 
+    __defaults: Dict[str, any]
     __values: Dict[str, any]
     __values_override: Dict[str, any]
+    __default_overrides: Dict[str, Tuple[any, Callable]]
     __cached: Dict[str, any]
     __cached_configs: Dict[str, 'Configs']
 
@@ -112,8 +115,10 @@ class Configs:
 
     def __init__(self, *, _primary: str = None):
         self._primary = _primary
+        self.__defaults = {}
         self.__values = {}
         self.__values_override = {}
+        self.__default_overrides = {}
         self.__cached = {}
         self.__cached_configs = {}
 
@@ -159,7 +164,7 @@ class Configs:
                     continue
 
                 if v.has_value:
-                    self.__values[k] = v.value
+                    self.__defaults[k] = v.value
 
                 if k in self.__config_items:
                     self.__config_items[k].update(v)
@@ -246,21 +251,31 @@ class Configs:
         for k, options in self.__aggregates[item].items():
             v, has = self.__get_value(k)
             if has and v in options:
+                if k not in self.__cached:
+                    self.__calculate(k)
                 return options[v], True
 
         return None, False
 
-    def __get_value_direct(self, item):
+    def __get_value_direct(self, item: str) -> Tuple[Any, bool]:
         if item in self.__values_override:
             return self.__values_override[item], True
-        elif item in self.__values:
+
+        if item in self.__values:
             return self.__values[item], True
-        else:
-            return None, False
+
+        if item in self.__default_overrides:
+            v, f = self.__default_overrides[item]
+            if f is None:
+                return v, True
+            else:
+                return f(), True
+
+        return None, False
 
     def __get_value(self, item):
         if item in self.__cached:
-            return self.__cached[item]
+            return self.__cached[item], True
 
         value, has = self.__get_value_direct(item)
 
@@ -271,6 +286,9 @@ class Configs:
         if has:
             return value, has
 
+        if item in self.__defaults:
+            return self.__defaults[item], True
+
         if item in self.__options:
             return next(iter(self.__options[item].keys())), True
 
@@ -293,7 +311,7 @@ class Configs:
 
             self.__options[item] = OrderedDict()
             self.__options[item]['from_type'] = config_function
-            self.__values[item] = 'from_type'
+            self.__defaults[item] = 'from_type'
             value = 'from_type'
         else:
             raise AttributeError(f"{self.__class__.__name__} cannot calculate config `{item}`")
@@ -488,7 +506,7 @@ class Configs:
                 'computed': Value.to_yaml_truncated(self.__cached.get(k, None)),
                 'is_hyperparam': self.__hyperparams.get(k, None),
                 'is_meta': self.__meta.get(k, None),
-                'is_explicitly_specified': (k in self.__explicitly_specified)
+                'is_explicitly_specified': (k in self.__explicitly_specified),
             }
 
         for k, c in self.__cached_configs.items():
@@ -498,9 +516,12 @@ class Configs:
 
         return configs
 
+    def _get_computed(self, key: str):
+        return self.__cached.get(key, None)
+
     def _reset_explicitly_specified(self):
         self.__explicitly_specified = set()
-        for k, v in self.__cached_configs:
+        for k, v in self.__cached_configs.items():
             v._reset_explicitly_specified()
 
     def _set_update_callback(self, update_callback: Callable):
@@ -508,3 +529,11 @@ class Configs:
 
     def _get_type(self, item: str) -> Type:
         return self.__types[item]
+
+    def set_default(self, item: Any, value: Any = None, func: Optional[Callable] = None):
+        if isinstance(item, ConfigItem):
+            item = item.key
+        else:
+            warnings.warn(f"Use Config.{item} when setting defaults", FutureWarning, 4)
+
+        self.__default_overrides[item] = (value, func)
